@@ -9,17 +9,15 @@ use deno_core::error::not_supported;
 use deno_core::error::type_error;
 use deno_core::error::AnyError;
 use deno_core::include_js_files;
-use deno_core::op_async;
-use deno_core::op_sync;
+use deno_core::op;
+
 use deno_core::Extension;
 use deno_core::OpState;
 use deno_core::ZeroCopyBuf;
 use serde::Deserialize;
 use shared::operation_error;
 
-use std::cell::RefCell;
 use std::num::NonZeroU32;
-use std::rc::Rc;
 
 use p256::elliptic_curve::sec1::FromEncodedPoint;
 use p256::pkcs8::FromPrivateKey;
@@ -53,7 +51,6 @@ use sha2::Sha256;
 use sha2::Sha384;
 use sha2::Sha512;
 use std::convert::TryFrom;
-use std::path::PathBuf;
 
 pub use rand; // Re-export rand
 
@@ -89,22 +86,19 @@ pub fn init(maybe_seed: Option<u64>) -> Extension {
       "01_webidl.js",
     ))
     .ops(vec![
-      (
-        "op_crypto_get_random_values",
-        op_sync(op_crypto_get_random_values),
-      ),
-      ("op_crypto_generate_key", op_async(op_crypto_generate_key)),
-      ("op_crypto_sign_key", op_async(op_crypto_sign_key)),
-      ("op_crypto_verify_key", op_async(op_crypto_verify_key)),
-      ("op_crypto_derive_bits", op_async(op_crypto_derive_bits)),
-      ("op_crypto_import_key", op_sync(op_crypto_import_key)),
-      ("op_crypto_export_key", op_sync(op_crypto_export_key)),
-      ("op_crypto_encrypt", op_async(op_crypto_encrypt)),
-      ("op_crypto_decrypt", op_async(op_crypto_decrypt)),
-      ("op_crypto_subtle_digest", op_async(op_crypto_subtle_digest)),
-      ("op_crypto_random_uuid", op_sync(op_crypto_random_uuid)),
-      ("op_crypto_wrap_key", op_sync(op_crypto_wrap_key)),
-      ("op_crypto_unwrap_key", op_sync(op_crypto_unwrap_key)),
+      op_crypto_get_random_values::decl(),
+      op_crypto_generate_key::decl(),
+      op_crypto_sign_key::decl(),
+      op_crypto_verify_key::decl(),
+      op_crypto_derive_bits::decl(),
+      op_crypto_import_key::decl(),
+      op_crypto_export_key::decl(),
+      op_crypto_encrypt::decl(),
+      op_crypto_decrypt::decl(),
+      op_crypto_subtle_digest::decl(),
+      op_crypto_random_uuid::decl(),
+      op_crypto_wrap_key::decl(),
+      op_crypto_unwrap_key::decl(),
     ])
     .state(move |state| {
       if let Some(seed) = maybe_seed {
@@ -115,10 +109,10 @@ pub fn init(maybe_seed: Option<u64>) -> Extension {
     .build()
 }
 
+#[op]
 pub fn op_crypto_get_random_values(
   state: &mut OpState,
   mut zero_copy: ZeroCopyBuf,
-  _: (),
 ) -> Result<(), AnyError> {
   if zero_copy.len() > 65536 {
     return Err(
@@ -171,8 +165,8 @@ pub struct SignArg {
   named_curve: Option<CryptoNamedCurve>,
 }
 
+#[op]
 pub async fn op_crypto_sign_key(
-  _state: Rc<RefCell<OpState>>,
   args: SignArg,
   zero_copy: ZeroCopyBuf,
 ) -> Result<ZeroCopyBuf, AnyError> {
@@ -325,8 +319,8 @@ pub struct VerifyArg {
   named_curve: Option<CryptoNamedCurve>,
 }
 
+#[op]
 pub async fn op_crypto_verify_key(
-  _state: Rc<RefCell<OpState>>,
   args: VerifyArg,
   zero_copy: ZeroCopyBuf,
 ) -> Result<bool, AnyError> {
@@ -485,8 +479,8 @@ pub struct DeriveKeyArg {
   info: Option<ZeroCopyBuf>,
 }
 
+#[op]
 pub async fn op_crypto_derive_bits(
-  _state: Rc<RefCell<OpState>>,
   args: DeriveKeyArg,
   zero_copy: Option<ZeroCopyBuf>,
 ) -> Result<ZeroCopyBuf, AnyError> {
@@ -790,11 +784,8 @@ impl<'a> TryFrom<rsa::pkcs8::der::asn1::Any<'a>>
   }
 }
 
-pub fn op_crypto_random_uuid(
-  state: &mut OpState,
-  _: (),
-  _: (),
-) -> Result<String, AnyError> {
+#[op]
+pub fn op_crypto_random_uuid(state: &mut OpState) -> Result<String, AnyError> {
   let maybe_seeded_rng = state.try_borrow_mut::<StdRng>();
   let uuid = if let Some(seeded_rng) = maybe_seeded_rng {
     let mut bytes = [0u8; 16];
@@ -809,8 +800,8 @@ pub fn op_crypto_random_uuid(
   Ok(uuid.to_string())
 }
 
+#[op]
 pub async fn op_crypto_subtle_digest(
-  _state: Rc<RefCell<OpState>>,
   algorithm: CryptoHash,
   data: ZeroCopyBuf,
 ) -> Result<ZeroCopyBuf, AnyError> {
@@ -832,8 +823,8 @@ pub struct WrapUnwrapKeyArg {
   algorithm: Algorithm,
 }
 
+#[op]
 pub fn op_crypto_wrap_key(
-  _state: &mut OpState,
   args: WrapUnwrapKeyArg,
   data: ZeroCopyBuf,
 ) -> Result<ZeroCopyBuf, AnyError> {
@@ -861,8 +852,8 @@ pub fn op_crypto_wrap_key(
   }
 }
 
+#[op]
 pub fn op_crypto_unwrap_key(
-  _state: &mut OpState,
   args: WrapUnwrapKeyArg,
   data: ZeroCopyBuf,
 ) -> Result<ZeroCopyBuf, AnyError> {
@@ -890,7 +881,3 @@ pub fn op_crypto_unwrap_key(
     _ => Err(type_error("Unsupported algorithm")),
   }
 }
-
-pub fn get_declaration() -> PathBuf {
-  PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("lib.deno_crypto.d.ts")
-}
